/**** Bibliotheque graphique ****/

/** Fichiers d'inclusion **/

#include "SDL/SDL.h"

/** Types **/

typedef struct { int r,v,b; } couleur;

/** Constantes **/

#define BITS_PAR_PIXEL	32

static const couleur couleurs[]={
  {255,255,255},
  {0,0,0},
  {255,0,0},
  {0,255,0},
  {0,0,255},
  {255,105,180},
  {-1,-1,-1}
  };

/** Variables globales **/

static SDL_Surface *surface;

/** Fonctions **/

/* Initialisation de la surface dessinable */

unsigned char creerSurface(int largeur,int hauteur,char *titre){
SDL_Init(SDL_INIT_VIDEO);
SDL_WM_SetCaption(titre,titre);
surface=SDL_SetVideoMode(largeur,hauteur,BITS_PAR_PIXEL,0);
return (surface!=NULL);
}

/* Fermeture de la surface dessinable */

void fermerSurface(void){
if(surface!=NULL) SDL_FreeSurface(surface);
SDL_Quit();
}

/* Creation d'une couleur */

static int creerCouleur(int ncouleur){
couleur c=couleurs[ncouleur];
return SDL_MapRGB(surface->format,c.r,c.v,c.b);
}

/* Dessin d'un rectangle plein */

void rectanglePlein(int x,int y,int l,int h,int c){
SDL_Rect rectangle={x,y,l,h};
SDL_FillRect(surface,&rectangle,creerCouleur(c));
SDL_Flip(surface);
}

/* Manipulation de copie de surface en BMP */

int sauverSurface(char *fichier){ return SDL_SaveBMP(surface,fichier); }

unsigned char chargerSurface(char *fichier){
SDL_Surface *image=SDL_LoadBMP(fichier);
if(image!=NULL){
  SDL_BlitSurface(image,NULL,surface,NULL);
  SDL_Flip(surface);
  }
return (image!=NULL);
}

/* Trouver la couleur d'un pixel */

int couleurPixel(int x,int y){
int bpp=surface->format->BytesPerPixel;
Uint32 *p=(Uint32 *)(surface->pixels+y*surface->pitch+x*bpp);
Uint8 r,v,b;
SDL_GetRGB(*p,surface->format,&r,&v,&b);
int i=0;
while(1){
  if(couleurs[i].r<0) break;
  if(r==couleurs[i].r && v==couleurs[i].v && b==couleurs[i].b) break;
  i++;
  }
if(couleurs[i].r<0) return -1; else return i;
}

/* Attendre l'appui d'une touche */

void attendreEvenement(void){
SDL_Event event;
while(SDL_WaitEvent(&event))
  switch(event.type){
    case SDL_KEYDOWN:
    case SDL_MOUSEBUTTONDOWN:
    case SDL_QUIT:
      return;
    }
}
